@@ -38,12 +38,14 @@ def initialize():
     initialize_command.print_class_parameter()
     # get account id to initialize collect class
     account_id=initialize_command.get_account_id()
-
+    user_aws_access_key_id=initialize_command.get_aws_access_key_id()
+    user_aws_secret_access_key=initialize_command.get_aws_secret_access_key()
     # get the region
     regions=initialize_command.get_region()
     for region in regions:
         # initialize class
-        collect_command = Collect(region,account_id)
+        collect_command = Collect(region,account_id,user_aws_access_key_id,
+        user_aws_secret_access_key)
 
         # call command functions
         collect_command.get_lambda_list()
@@ -107,6 +109,8 @@ def initialize():
         prepare_command.prepare_sfn_node()
         prepare_command.prepare_apigw_node()
         prepare_command.prepare_cognito_node()
+        prepare_command.prepare_rds_node()
+        prepare_command.prepare_ec2_node()
         # prepare edge logic
         prepare_command.find_sfn_connection()
         prepare_command.find_edge_lambda_to_sns()
@@ -147,11 +151,14 @@ def update():
     initialize_command.print_class_parameter()
     # get account_id 
     account_id=initialize_command.get_account_id()
+    user_aws_access_key_id=initialize_command.get_aws_access_key_id()
+    user_aws_secret_access_key=initialize_command.get_aws_secret_access_key()
     # get the region
     regions=initialize_command.get_region()
     for region in regions:
         # initialize class
-        collect_command = Collect(region,account_id)
+        collect_command = Collect(region,account_id,user_aws_access_key_id,
+        user_aws_secret_access_key)
 
         # call command functions
         collect_command.get_lambda_list()
@@ -215,6 +222,8 @@ def update():
         prepare_command.prepare_sfn_node()
         prepare_command.prepare_apigw_node()
         prepare_command.prepare_cognito_node()
+        prepare_command.prepare_rds_node()
+        prepare_command.prepare_ec2_node()
         # prepare edge logic
         prepare_command.find_sfn_connection()
         prepare_command.find_edge_lambda_to_sns()
