@@ -28,6 +28,7 @@ def sfn_prepare_node(region, account_id, cytoscape_node_data):
                     "region": region,
                     "name": sfn['name'],
                     "CreationDate" : sfn['creationDate'],
-                    "tag": sfn_tag
+                    "tag": sfn_tag,
+                    "cost_for_month": "0.65 USD",
                 }
             })
