@@ -7,7 +7,7 @@ def transcribe_prepare_node(region, account_id, cytoscape_node_data):
         './data/cloudtrail-start-transcription')  # list of files in the data directory
     for each_file in list_of_files:
         # since its all type str you can simply use startswith
-        if each_file.startswith('cloudtrail-start-transcription'):
+        if each_file.startswith('cloudtrail-start-transcription-'):
             print('Found a cloudtrail transcribe file')
             cytoscape_node_data.append({
                 "data": {
