@@ -3,8 +3,9 @@ import json
 import os
 
 
-def cloudwatch_get_cognito_log_event(region):
-    client = boto3.client('logs', region_name=region)
+def cloudwatch_get_cognito_log_event(region,AWS_ACCESS_KEY,AWS_SECRET_KEY):
+    client = boto3.client('logs', region_name=region,
+    aws_access_key_id=AWS_ACCESS_KEY,aws_secret_access_key=AWS_SECRET_KEY)
     try:
         response = client.filter_log_events(
             logGroupName='aws-cloudtrail-logs-758325631830-congito',
